@@ -5,10 +5,9 @@
 #' This function generates an interactive plot of an antares time series.
 #' 
 #' @param x
-#'   Object of class \code{antaresData}.
-#' @param y
-#'   Optional object of class \code{antaresData}. If it is specified, then two
-#'   charts are generated.
+#'   Object of class \code{antaresData}. Alternatively, it can be a list of 
+#'   \code{antaresData} objects. In this case, one chart is created for each
+#'   object.
 #' @param table
 #'   Name of the table to display when \code{x} is an \code{antaresDataList}
 #'   object.
@@ -57,15 +56,6 @@
 #'   Vector of colors
 #' @param ylab
 #'   Label of the Y axis.
-#' @param compare
-#'   An optional character vector containing names of parameters. When it is set,
-#'   two charts are outputed with their own input controls. Alternatively, it can
-#'   be a named list with names corresponding to parameter names and values being
-#'   list with the initial values of the given parameter for each chart.
-#' @param compareLayout
-#'   Only used if \code{y} or \code{compare} is not null. If it equals to "v", 
-#'   then charts are placed one above the other. If it equals to "h", they are
-#'   placed one next to the other.
 #' @param colorScaleOpts
 #'   A list of parameters that control the creation of color scales. It is used
 #'   only for heatmaps. See \code{\link{colorScaleOptions}}() for available
@@ -131,7 +121,7 @@
 #' }
 #' 
 #' @export
-plot.antaresData <- function(x, y = NULL, table = NULL, variable = NULL, elements = NULL, 
+tsPlot <- function(x, y = NULL, table = NULL, variable = NULL, elements = NULL, 
                              mcYear = "average",
                              type = c("ts", "barplot", "monotone", "density", "cdf", "heatmap"),
                              dateRange = NULL,
@@ -140,7 +130,7 @@ plot.antaresData <- function(x, y = NULL, table = NULL, variable = NULL, element
                              maxValue = NULL,
                              aggregate = c("none", "mean", "sum"),
                              compare = NULL,
-                             compareLayout = c("v", "h"),
+                             compareOpts = list(),
                              interactive = getInteractivity(),
                              colors = NULL,
                              main = NULL,
@@ -150,7 +140,6 @@ plot.antaresData <- function(x, y = NULL, table = NULL, variable = NULL, element
                              colorScaleOpts = colorScaleOptions(20),
                              width = NULL, height = NULL, ...) {
   
-  dataname <- deparse(substitute(x))
   type <- match.arg(type)
   aggregate <- match.arg(aggregate)
   colorScaleOpts <- do.call(colorScaleOptions, colorScaleOpts)
@@ -162,27 +151,14 @@ plot.antaresData <- function(x, y = NULL, table = NULL, variable = NULL, element
     group <- NULL
   }
   
-  x <- as.antaresDataList(x)
-  
-  timeStep <- attr(x, "timeStep")
-  compareLayout <- match.arg(compareLayout)
-  opts <- simOptions(x)
-  
-  if (is.null(compare)) {
-    if (!is.null(y)) compare <- list()
-  } else {
-    if (is.character(compare)) {
-      compare <- match.arg(
-        compare, 
-        c("table", "variable", "elements", "type", "dateRange", "minValue", "maxValue", "mcYear"),
-        several.ok = TRUE
-      )
-      tmp <- lapply(compare, function(x) NULL)
-      names(tmp) <- compare
-      compare <- tmp
-    }
-  }
+  # Preprocess data for comparison
+  tmp <- .getDataForComp(x, y, compare, compareOpts)
+  x <- tmp$x
+  compare <- tmp$compare
+  compareOpts <- tmp$compareOpts
   
+  timeStep <- attr(x[[1]], "timeStep")
+  opts <- simOptions(x[[1]])
   
   .prepareParams <- function(x) {
     idCols <- .idCols(x)
@@ -229,23 +205,11 @@ plot.antaresData <- function(x, y = NULL, table = NULL, variable = NULL, element
     )
   }
     
-  params <- list(
-    x = lapply(x, .prepareParams)
-  )
-  
-  if (!is.null(y)) {
-    if (!is(y, "antaresData")) stop("y should be an 'antaresData' object")
-    y <- as.antaresDataList(y)
-    params$y <- lapply(y, .prepareParams)
-    x <- list(x, y)
-  } else {
-    params$y <- params$x
-    x <- list(x, x)
-  }
+  params <- lapply(x, function(o) lapply(o, .prepareParams))
   
   # Function that generates the desired graphic.
   plotFun <- function(table, mcYear, id, variable, elements, type, confInt, dateRange, 
-                      minValue, maxValue, aggregate) {
+                      minValue, maxValue, aggregate, legend) {
     
     if (is.null(variable)) variable <- params[[id]][[table]]$valueCols[1]
     if (is.null(dateRange)) dateRange <- params[[id]][[table]]$dateRange
@@ -325,7 +289,7 @@ plot.antaresData <- function(x, y = NULL, table = NULL, variable = NULL, element
   
   manipulateWidget(
     plotFun(table, mcYear, .id, variable, elements, type, confInt, dateRange, minValue, 
-            maxValue, aggregate),
+            maxValue, aggregate, legend),
     
     table = mwSelect(names(params[[.id]]), value = table, .display = length(params[[.id]]) > 1),
     mcYear = mwSelect(
@@ -362,10 +326,13 @@ plot.antaresData <- function(x, y = NULL, table = NULL, variable = NULL, element
       multiple = TRUE
     ),
     aggregate = mwSelect(c("none", "mean", "sum"), aggregate),
-    
-    .main = dataname,
+    legend = mwCheckbox(legend, .display = type %in% c("ts", "density", "cdf")),
     .compare = compare,
-    .compareLayout = compareLayout
+    .compareOpts = compareOpts
   )
   
 }
+
+#' @export
+#' @rdname tsPlot
+plot.antaresData <- tsPlot
